==> localcider-0.1.9.post1.tar.gz: localcider-0.1.9.post1/localcider/backend/residue.py <==
"""
   !--------------------------------------------------------------------------!
   ! LICENSE INFO:                                                            !
   !--------------------------------------------------------------------------!
   !    This file is part of localCIDER.                                      !
   !                                                                          !
   !    Version 0.1.9                                                         !
   !                                                                          !
   !    Copyright (C) 2014 - 2016                                             !
   !    The localCIDER development team (current and former contributors)     !
   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
   !                                                                          !
   !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
   !    University in St. Louis. Please see the website for citation          !
   !    information:                                                          !
   !                                                                          !
   !    http://pappulab.github.io/localCIDER/                                 !
   !                                                                          !
   !    For more information please see the Pappu lab website:                !
   !                                                                          !
   !    http://pappulab.wustl.edu/                                            !
   !                                                                          !
   !    localCIDER is free software: you can redistribute it and/or modify    !
   !    it under the terms of the GNU General Public License as published by  !
   !    the Free Software Foundation, either version 3 of the License, or     !
   !    (at your option) any later version.                                   !
   !                                                                          !
   !    localCIDER is distributed in the hope that it will be useful,         !
   !    but WITHOUT ANY WARRANTY; without even the implied warranty of        !
   !    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         !
   !    GNU General Public License for more details.                          !
   !                                                                          !
   !    You should have received a copy of the GNU General Public License     !
   !    along with localCIDER.  If not, see <http://www.gnu.org/licenses/>.   !
   !--------------------------------------------------------------------------!
   ! AUTHORSHIP INFO:                                                         !
   !--------------------------------------------------------------------------!
   !                                                                          !
   ! MAIN AUTHOR:   James Ahad                                                !
   !                                                                          !
   !--------------------------------------------------------------------------!


   File Description:
   ================

   Class which holds the properties of an amino acid residue

"""


class Residue:
    """
       Residue class which defines the properties for each residue.
    """

    def __init__(self, name, letterCode3, letterCode1, hydropathy, charge, PPII):
        self.name = name                      # full name     [glycine]
        self.letterCode3 = letterCode3        # 3 letter code [gly]
        self.letterCode1 = letterCode1        # 1 letter code [g]
        self.hydropathy = hydropathy          # hydropathy score
        self.charge = charge                  # charge
        self.PPII = PPII                      # PPII propensity (Hilser)

==> localcider-0.1.10.post1.tar.gz: localcider-0.1.10.post1/localcider/backend/residue.py <==
"""
   !--------------------------------------------------------------------------!
   ! LICENSE INFO:                                                            !
   !--------------------------------------------------------------------------!
   !    This file is part of localCIDER.                                      !
   !                                                                          !
   !    Version 0.1.10                                                        !
   !                                                                          !
   !    Copyright (C) 2014 - 2016                                             !
   !    The localCIDER development team (current and former contributors)     !
   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
   !                                                                          !
   !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
   !    University in St. Louis. Please see the website for citation          !
   !    information:                                                          !
   !                                                                          !
   !    http://pappulab.github.io/localCIDER/                                 !
   !                                                                          !
   !    For more information please see the Pappu lab website:                !
   !                                                                          !
   !    http://pappulab.wustl.edu/                                            !
   !                                                                          !
   !    localCIDER is free software: you can redistribute it and/or modify    !
   !    it under the terms of the GNU General Public License as published by  !
   !    the Free Software Foundation, either version 3 of the License, or     !
   !    (at your option) any later version.                                   !
   !                                                                          !
   !    localCIDER is distributed in the hope that it will be useful,         !
   !    but WITHOUT ANY WARRANTY; without even the implied warranty of        !
   !    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         !
   !    GNU General Public License for more details.                          !
   !                                                                          !
   !    You should have received a copy of the GNU General Public License     !
   !    along with localCIDER.  If not, see <http://www.gnu.org/licenses/>.   !
   !--------------------------------------------------------------------------!
   ! AUTHORSHIP INFO:                                                         !
   !--------------------------------------------------------------------------!
   !                                                                          !
   ! MAIN AUTHOR:   James Ahad                                                !
   !                                                                          !
   !--------------------------------------------------------------------------!


   File Description:
   ================

   Class which holds the properties of an amino acid residue

"""


class Residue:
    """
       Residue class which defines the properties for each residue.
    """

    def __init__(self, name, letterCode3, letterCode1, hydropathy, charge, PPII_Hilser, PPII_Creamer, PPII_Kallenbach):
        self.name = name                      # full name     [glycine]
        self.letterCode3 = letterCode3        # 3 letter code [gly]
        self.letterCode1 = letterCode1        # 1 letter code [g]
        self.hydropathy = hydropathy          # hydropathy score
        self.charge = charge                  # charge
        self.PPII = {'hilser':PPII_Hilser, 'creamer':PPII_Creamer, 'kallenbach': PPII_Kallenbach}
